%%
% Dispersion plot

close all
clear all
clc
%
addpath('_subprogs');

%% load and truncate data (waveforms)
%
sca      = 2;                           %%% scale dt
scn      = 5;                           %%% trucated waveforms
dt       = 0.84404e-6*sca;              %%% time step in seconds
dz       = 0.152;                       %%% receivers step in meters
tr       = 1.219;                       % distance between transmitter and 1st receiver (m)
flims    = [1000 15000];                %%% frequency limits (Hz)
freq_min = min(flims);                  %%% minimum frequency for F-K spectra/ V-F spectra
freq_max = max(flims);                  %%% maximum frequency for spectra / V-F spectra

%
multi_nt = 1;                           %%% multiplier for time-dimension (decrease the temporal frequency step, increases the spectral resolution)
multi_nr = 5;                          %%% multiplier for reciever-dimension (decrease the wavenumber step, increases the spectral resolution)
maxVelocity = 5000;                     %%% maximum velocity for V-F spectra in meters/seconds
%
slolims    = [50 2500];
clevel     = 0;
ct         = 2:2:20000;                 % A vector for the velocity of interest in m/s.
st         = 0:2:1000;
%
data    = load('aprs.txt');
[Nt,Nx] = size(data);
Ntt     = Nt/scn;
wfts    = data(1:sca:Ntt,1:Nx);
min_x   = 0;
max_x   = (Nx-1)*dz;
xd      = min_x:dz:max_x;         % spatial sampling vector (receiver position)
%
time   = 0:dt:((Ntt/sca)-1)*dt;
T      = max(time);
%
%% Compute FK Spectra and disperion curve by SFK-transform and MASW
tic
% using SFK transform
[fk2d, fk, vf2d, vf, freq, k] = SFK(wfts, dt, dz, freq_max, freq_min, multi_nt, multi_nr, maxVelocity);
norm_fk2d = fk2d./max(fk2d,[],2);   %%% normalization FK spectra by frequency
norm_vf2d = vf2d./max(vf2d,[],1);   %%% normalization VF spectra by frequency
%
% using MASW transform

%
%
%
%% Plot results

figure('Name', 'Dispersion','NumberTitle','off','units','normalized','outerposition',[0 0 1 1])
%
subplot(1,3,1);
gain = 1;
pltseism(data,dt,gain); title('Waveforms');
xlim([0 0.02])
ylabel('No. of receivers'); xlabel('Time (s)'); 
%
subplot(1,3,2);
imagesc(k,freq/1e3,norm_fk2d); colormap jet; axis xy; title('F-K spectra');
xlabel('Wavenumber (1/m)'); ylabel('Frequency (kHz)');
hold on
plot(fk,freq,'-k');
%
[f,veldata] = vel_imag(Ntt,T,wfts,dz,dt,ct,xd);
subplot(1,3,3);
h = pcolor(f/1e3,(1./ct).*1e6,veldata); % plot the normalized dispersion image
set(h, 'EdgeColor', 'none');
colormap(jet)
hold on
if strcmp('none',flims) == 1 % check for plotting limits
    % if 'none' then ignore the xlim
else
    xlim([0 15]) % set the xlim if specified
    ylim(slolims);
end
ylabel('Phase Slowness (\mus/m)')
xlabel('Frequency (kHz)')
title('Dispersion')
hold off
toc











